@@ -24,10 +24,11 @@ Coro - coroutine process abstraction
 
 package Coro;
 
-use base Coro::State;
+use Coro::State;
+
 use base Exporter;
 
-$VERSION = 0.03;
+$VERSION = 0.04;
 
 @EXPORT = qw(async yield schedule);
 @EXPORT_OK = qw($current);
@@ -60,17 +61,13 @@ $VERSION = 0.03;
    }
 }
 
-my $idle = new Coro sub {
-   &yield while 1;
-};
-
 =item $main
 
 This coroutine represents the main program.
 
 =cut
 
-$main = new Coro;
+our $main = new Coro;
 
 =item $current
 
@@ -78,7 +75,25 @@ The current coroutine (the last coroutine switched to). The initial value is C<$
 
 =cut
 
-$current = $main;
+# maybe some other module used Coro::Specific before...
+if ($current) {
+   $main->{specific} = $current->{specific};
+}
+
+our $current = $main;
+
+=item $idle
+
+The coroutine to switch to when no other coroutine is running. The default
+implementation prints "FATAL: deadlock detected" and exits.
+
+=cut
+
+# should be done using priorities :(
+our $idle = new Coro sub {
+   print STDERR "FATAL: deadlock detected\n";
+   exit(51);
+};
 
 # we really need priorities...
 my @ready = (); # the ready queue. hehe, rather broken ;)
@@ -100,7 +115,9 @@ terminated.
 =cut
 
 sub async(&) {
-   new Coro $_[0];
+   my $pid = new Coro $_[0];
+   $pid->ready;
+   $pid;
 }
 
 =item schedule
@@ -114,7 +131,8 @@ never be called again.
 my $prev;
 
 sub schedule {
-   ($prev, $current) = ($current, shift @ready);
+   # should be done using priorities :(
+   ($prev, $current) = ($current, shift @ready || $idle);
    Coro::State::transfer($prev, $current);
 }
 
@@ -152,17 +170,18 @@ These are the methods you can call on process objects.
 
 =item new Coro \&sub;
 
-Create a new process, put it into the ready queue and return it. When the
-sub returns the process automatically terminates.
+Create a new process and return it. When the sub returns the process
+automatically terminates. To start the process you must first put it into
+the ready queue by calling the ready method.
 
 =cut
 
 sub new {
    my $class = shift;
-   my $proc = shift;
-   my $self = $class->SUPER::new($proc ? sub { &$proc; &terminate } : $proc);
-   $self->ready;
-   $self;
+   my $proc = $_[0];
+   bless {
+      _coro_state => new Coro::State ($proc ? sub { &$proc; &terminate } : $proc),
+   }, $class;
 }
 
 =item $process->ready
@@ -181,6 +200,11 @@ sub ready {
 
 1;
 
+=head1 SEE ALSO
+
+L<Coro::Channel>, L<Coro::Cont>, L<Coro::Specific>, L<Coro::Semaphore>,
+L<Coro::Signal>, L<Coro::State>, L<Coro::Event>.
+
 =head1 AUTHOR
 
  Marc Lehmann <pcg@goof.com>
