@@ -76,13 +76,17 @@ sub new {
 Save the state of the current subroutine in C<$prev> and switch to the
 coroutine saved in C<$next>.
 
-The "state" of a subroutine only ever includes scope, i.e. lexical
-variables and the current execution state. It does not save/restore any
-global variables such as C<$_> or C<$@> or any other special or non
-special variables. So remember that every function call that might call
-C<transfer> (such as C<Coro::Channel::put>) might clobber any global
-and/or special variables. Yes, this is by design ;) You cna always create
-your own process abstraction model that saves these variables.
+The "state" of a subroutine includes the scope, i.e. lexical variables
+and the current execution state as well as the following global
+variables:
+
+  @_
+
+If you feel that something important is missing tell me.  Also
+remember that every function call that might call C<transfer> (such
+as C<Coro::Channel::put>) might clobber any global and/or special
+variables. Yes, this is by design ;) You can always create your own
+process abstraction model that saves these variables.
 
 The easiest way to do this is to create your own scheduling primitive like this:
 
@@ -91,6 +95,15 @@ The easiest way to do this is to create your own scheduling primitive like this:
      $old->transfer($new);
   }
 
+IMPLEMENTORS NOTE: all Coro::State functions/methods expect either the
+usual Coro::State object or a hashref with a key named "_coro_state" that
+contains the real Coro::State object. That is, you can do:
+
+  $obj->{_coro_state} = new Coro::State ...;
+  Coro::State::transfer(..., $obj);
+
+This exists mainly to ease subclassing (wether through @ISA or not).
+
 =cut
 
 =item $error->($error_coro, $error_msg)
